@@ -6,10 +6,11 @@ from datetime import datetime
 from itertools import combinations
 from typing import Any, Literal, Pattern
 
-import fsutil
 from dateutil import parser as date_parser
 from slugify import slugify
 
+from codicefiscale.data import get_indexed_data
+
 _CONSONANTS: list[str] = list("bcdfghjklmnpqrstvwxyz")
 _VOWELS: list[str] = list("aeiou")
 _MONTHS: list[str] = list("ABCDEHLMPRST")
@@ -65,7 +66,7 @@ _OMOCODIA: dict[str, str] = {
     "8": "U",
     "9": "V",
 }
-_OMOCODIA_DIGITS: str = "".join([digit for digit in _OMOCODIA])
+_OMOCODIA_DIGITS: str = "".join(list(_OMOCODIA))
 _OMOCODIA_LETTERS: str = "".join([_OMOCODIA[digit] for digit in _OMOCODIA])
 _OMOCODIA_ENCODE_TRANS: dict[int, int] = "".maketrans(
     _OMOCODIA_DIGITS, _OMOCODIA_LETTERS
@@ -80,47 +81,7 @@ for combo_size in range(1, len(_OMOCODIA_SUBS_INDEXES) + 1):
         _OMOCODIA_SUBS_INDEXES_COMBINATIONS.append(list(combo))
 
 
-def _get_data(filename: str) -> Any:
-    return fsutil.read_file_json(fsutil.join_path(__file__, f"data/{filename}"))
-
-
-def _get_indexed_data() -> (
-    dict[str, dict[str, list[dict[str, bool | datetime | str | list[str]]]]]
-):
-    municipalities = _get_data("municipalities.json")
-    countries = _get_data("countries.json")
-    data: dict[str, dict[str, list[dict[str, bool | datetime | str | list[str]]]]] = {
-        "municipalities": {},
-        "countries": {},
-        "codes": {},
-    }
-
-    for municipality in municipalities:
-        code = municipality["code"]
-        province = municipality["province"].lower()
-        names = municipality["name_slugs"]
-        for name in names:
-            name_and_province = f"{name}-{province}"
-            data["municipalities"].setdefault(name, [])
-            data["municipalities"].setdefault(name_and_province, [])
-            data["municipalities"][name].append(municipality)
-            data["municipalities"][name_and_province].append(municipality)
-        data["codes"].setdefault(code, [])
-        data["codes"][code].append(municipality)
-
-    for country in countries:
-        code = country["code"]
-        names = country["name_slugs"]
-        for name in names:
-            data["countries"].setdefault(name, [])
-            data["countries"][name].append(country)
-        data["codes"].setdefault(code, [])
-        data["codes"][code].append(country)
-
-    return data
-
-
-_DATA: dict[str, dict[str, list[dict[str, Any]]]] = _get_indexed_data()
+_DATA: dict[str, dict[str, list[dict[str, Any]]]] = get_indexed_data()
 
 CODICEFISCALE_RE: Pattern[str] = re.compile(
     r"^"
@@ -468,7 +429,8 @@ def decode(code: str) -> dict[str, Any]:
 
     current_year = datetime.now().year
     current_year_century_prefix = str(current_year)[0:-2]
-    birthdate_year = int(f"{current_year_century_prefix}{birthdate_year}")
+    birthdate_year_suffix = str(birthdate_year).zfill(2)
+    birthdate_year = int(f"{current_year_century_prefix}{birthdate_year_suffix}")
     if birthdate_year > current_year:
         birthdate_year -= 100
     birthdate_str = f"{birthdate_year}/{birthdate_month}/{birthdate_day}"
@@ -482,7 +444,10 @@ def decode(code: str) -> dict[str, Any]:
     birthplace = _get_birthplace(birthplace_code, birthdate)
     # print(birthplace)
     if not birthplace:
-        raise ValueError(f"[codicefiscale] wrong birthplace code: {birthplace_code!r}")
+        raise ValueError(
+            "[codicefiscale] wrong birthplace code: "
+            f"{birthplace_code!r} / birthdate: {birthdate.isoformat()!r}."
+        )
 
     cin = raw["cin"]
     cin_check = encode_cin(code)
